paper-item demo

#### Single line items

Inbox Starred Sent mail Drafts

#### Icon with text

Inbox Outbox Trash Spam

#### Avatar with text

Alphonso Engelking
Andrews Boyd
Angela Decker
Lorem Ipsum

#### Avatar with text and icon

Alphonso
Andrews
Angela
Lorem

#### Avatar with text and control

Alphonso
Andrews
Angela
Lorem

#### Control with text and icon

Alphonso
Andrews
Angela
Lorem

#### Two-line items

Profile Photo
Change your Google+ profile photo
Show your status
Your status is visible to everyone you use with
Settings
Change your account settings

#### Icon with two-line text

Alphonso Engelking
Change photo
(650) 555-1234
Mobile
alphonso@example.com
Personal

#### Avatar with text and icon

Photos
Jan 9, 2014
Recipes
Jan 17, 2014
Work
Jan 28, 2014